@@ -1,16 +1,14 @@
-import inspect
 import logging
 import os
-import sys
 from typing import Any, Dict, List
 
 import requests
 from requests.packages.urllib3.exceptions import InsecureRequestWarning
 
+import rumpy.utils as utils
+from rumpy.exceptions import *
+
 requests.packages.urllib3.disable_warnings(InsecureRequestWarning)
-
-from rumpy import api
-
 logger = logging.getLogger(__name__)
 
 
@@ -25,7 +23,7 @@ class HttpRequest:
         requests.adapters.DEFAULT_RETRIES = 5
         self.api_base = api_base
         self._session = requests.Session()
-        self._session.verify = crtfile or False
+        self._session.verify = utils.check_crtfile(crtfile)
         self._session.keep_alive = False
         self._session.headers.update(
             {
@@ -35,12 +33,17 @@ class HttpRequest:
         )
         if jwt_token:
             self._session.headers.update({"Authorization": f"Bearer {jwt_token}"})
-        if "127.0.0.1" in self.api_base:
-            os.environ["NO_PROXY"] = ",".join([os.getenv("NO_PROXY", ""), self.api_base])
+
+        _no_proxy = os.getenv("NO_PROXY", "")
+        if "127.0.0.1" in api_base and api_base not in _no_proxy:
+            os.environ["NO_PROXY"] = ",".join([_no_proxy, api_base])
 
     def _request(self, method: str, endpoint: str, payload: Dict = {}, api_base=None):
-        api_base = api_base or self.api_base or ""
-        url = api_base + endpoint
+        api_base = api_base or self.api_base
+        if not api_base:
+            raise ParamValueError(f"api_base is null, {api_base}")
+        url = utils.get_url(api_base, endpoint)
+
         try:
             resp = self._session.request(method=method, url=url, json=payload)
         except Exception as e:  # SSLCertVerificationError
@@ -54,7 +57,11 @@ class HttpRequest:
             body_json = {}
 
         if resp.status_code != 200:
-            logger.warning(f"{resp.status_code}, {resp.json()}")
+            logger.info(f"body_json:{body_json}")
+            logger.info(f"resp.status_code:{resp.status_code}")
+            logger.info(f"payload:{payload.keys()}")
+            logger.info(f"url:{url}")
+
         return body_json
 
     def get(self, endpoint: str, payload: Dict = {}, api_base=None):
